==> knmap-trinity_14.0.8.orig.tar.xz: knmap-trinity-14.0.8/src/tabwidgetptrlist.cpp <==
/***************************************************************************
 *                                                                         *
 *   Copyright (C) 2005, 2006 by Kevin Gilbert                             *
 *   kev.gilbert@cdu.edu.au                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 *                                                                         *
 ***************************************************************************/

#include <ntqptrcollection.h>

#include <kdebug.h>
#include <tdelocale.h>

#include "tabwidgetptrlist.h"

//	constructor
//	===========

TabWidgetPtrList::TabWidgetPtrList( )
{	setAutoDelete( true );
}

//	compareItems
//	============

int TabWidgetPtrList::compareItems( TQPtrCollection::Item item1, TQPtrCollection::Item item2 )
{	typedef TabWidgetData* DataPtr;

	if( DataPtr( item1 )->index( ) < DataPtr( item2 )->index( ))
		return -1;

	return DataPtr( item1 )->index( ) != DataPtr( item2 )->index( );
}

==> knmap-trinity-14.1.5.tar.xz: knmap-trinity-14.1.5/src/tabwidgetptrlist.cpp <==
/***************************************************************************
 *                                                                         *
 *   Copyright (C) 2005, 2006 by Kevin Gilbert                             *
 *   kev.gilbert@cdu.edu.au                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 *                                                                         *
 ***************************************************************************/

#include <tqptrcollection.h>

#include <kdebug.h>
#include <tdelocale.h>

#include "tabwidgetptrlist.h"

//	constructor
//	===========

TabWidgetPtrList::TabWidgetPtrList( )
{	setAutoDelete( true );
}

//	compareItems
//	============

int TabWidgetPtrList::compareItems( TQPtrCollection::Item item1, TQPtrCollection::Item item2 )
{	typedef TabWidgetData* DataPtr;

	if( DataPtr( item1 )->index( ) < DataPtr( item2 )->index( ))
		return -1;

	return DataPtr( item1 )->index( ) != DataPtr( item2 )->index( );
}
